==> openshift-model-config-6.3.1-sources.jar: io/fabric8/openshift/api/model/config/v1/RepositoryDigestMirrorsFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface RepositoryDigestMirrorsFluent<A extends RepositoryDigestMirrorsFluent<A>> extends Fluent<A>{
  public Boolean getAllowMirrorByTags();
  public A withAllowMirrorByTags(Boolean allowMirrorByTags);
  public Boolean hasAllowMirrorByTags();
  public A addToMirrors(Integer index,String item);
  public A setToMirrors(Integer index,String item);
  public A addToMirrors(java.lang.String... items);
  public A addAllToMirrors(Collection<String> items);
  public A removeFromMirrors(java.lang.String... items);
  public A removeAllFromMirrors(Collection<String> items);
  public List<String> getMirrors();
  public String getMirror(Integer index);
  public String getFirstMirror();
  public String getLastMirror();
  public String getMatchingMirror(Predicate<String> predicate);
  public Boolean hasMatchingMirror(Predicate<String> predicate);
  public A withMirrors(List<String> mirrors);
  public A withMirrors(java.lang.String... mirrors);
  public Boolean hasMirrors();
  public String getSource();
  public A withSource(String source);
  public Boolean hasSource();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withAllowMirrorByTags();
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/RepositoryDigestMirrorsFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface RepositoryDigestMirrorsFluent<A extends RepositoryDigestMirrorsFluent<A>> extends Fluent<A>{
  public Boolean getAllowMirrorByTags();
  public A withAllowMirrorByTags(Boolean allowMirrorByTags);
  public Boolean hasAllowMirrorByTags();
  public A addToMirrors(int index,String item);
  public A setToMirrors(int index,String item);
  public A addToMirrors(java.lang.String... items);
  public A addAllToMirrors(Collection<String> items);
  public A removeFromMirrors(java.lang.String... items);
  public A removeAllFromMirrors(Collection<String> items);
  public List<String> getMirrors();
  public String getMirror(int index);
  public String getFirstMirror();
  public String getLastMirror();
  public String getMatchingMirror(Predicate<String> predicate);
  public Boolean hasMatchingMirror(Predicate<String> predicate);
  public A withMirrors(List<String> mirrors);
  public A withMirrors(java.lang.String... mirrors);
  public Boolean hasMirrors();
  public String getSource();
  public A withSource(String source);
  public Boolean hasSource();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withAllowMirrorByTags();
  
}
